if select(2, UnitClass("player")) ~= "DEATHKNIGHT" then
   return
end

------------------------------------------------------------------------

FF_Icon = "Interface\\Icons\\Spell_DeathKnight_FrostFever";
BP_Icon = "Interface\\Icons\\Spell_DeathKnight_BloodPlague";


TRB_Diseases = CreateFrame("frame", nil, UIParent);

function TRB_Diseases:SavePosition()
	TRB_Config["Positions"]["diseases"] = { self:GetPoint() };
end

function TRB_Diseases:LoadPosition()
	self:SetPoint( unpack(TRB_Config["Positions"]["diseases"]) );
end

function TRB_Diseases:Disable()
	self:Hide();
	self:UnregisterAllEvents();
	self:SetScript("OnUpdate", nil);
	self.isRunning = nil;
	DEFAULT_CHAT_FRAME:AddMessage("TRB: Diseases module disabled.");
end

function TRB_Diseases:init()
	if( self.isRunning ) then return; end -- Nothing to do

	if( not self.Bars ) then

		-- Create move frame
			f = CreateFrame("frame", nil, self);
			f.parent = self;
			f:SetAllPoints(self);
			self:SetMovable(true);
			f:EnableMouse(true);
			f:RegisterForDrag("LeftButton");
			f:SetScript("OnDragStart", function(frame) frame.parent:StartMoving() end );
			f:SetScript("OnDragStop", function(frame) frame.parent:StopMovingOrSizing(); frame.parent:SavePosition() end );
			
			f.bg = f:CreateTexture(nil, "ARTWORK");
			f.bg:SetAllPoints(f);
			f.bg:SetTexture(0.8,0.8,0.8, 0.4);
			f:SetFrameStrata("HIGH");
			f:Hide();
			
			self.moveFrame = f;
		-- Move frame done
		
		-- Set Position and size
		self:ClearAllPoints();
		self:SetWidth(122);
		self:SetHeight(40);
		self:SetPoint( unpack(TRB_Config["Positions"]["diseases"]) );
		self:SetFrameStrata("HIGH"); -- Set to HIGH framestrata to be visible ontop of Blizzards "Power Aura" thing
		self:Hide();
		
		-- Background
		local bg = self:CreateTexture(nil, "BACKGROUND");
		bg:SetWidth(128);
		bg:SetHeight(128);
		bg:SetPoint("CENTER", self, "CENTER", 0, 0);
		bg:SetTexture("Interface\\AddOns\\ThreeRuneBars\\diseases.tga");
		self.bg = bg;
		
		local ff = TRB_Runes:CreateBar("Frost_Fever", self);
		local bp = TRB_Runes:CreateBar("Blood_Plague", self);
		
		ff:SetValue(0);
		bp:SetValue(0);
		
		ff:SetWidth(98);
		bp:SetWidth(98);
		ff:SetStatusBarColor(TRB_Config.Colors["ff"][1], TRB_Config.Colors["ff"][2], TRB_Config.Colors["ff"][3]);
		bp:SetStatusBarColor(TRB_Config.Colors["bp"][1], TRB_Config.Colors["bp"][2], TRB_Config.Colors["bp"][3]);
		ff:Show();
		bp:Show();
		
		ff.id = "Frost Fever";
		bp.id = "Blood Plague";
		
		ff:SetPoint("TOPLEFT", self, "TOPLEFT", 22, -6);
		bp:SetPoint("TOPLEFT", self, "TOPLEFT", 22, -26);
		
		-- Text
		local text = ff:CreateFontString(nil, "ARTWORK", "GameFontHighlightExtraSmall");
		text:SetPoint("CENTER", ff, "CENTER", 0, 0);
		text:SetText();
		ff.text = text;
		text = bp:CreateFontString(nil, "ARTWORK", "GameFontHighlightExtraSmall");
		text:SetPoint("CENTER", bp, "CENTER", 0, 0);
		text:SetText();
		bp.text = text;
		
		-- Create Icons
		ff.icon = self:CreateTexture(nil, "OVERLAY"); ff.icon:ClearAllPoints(); ff.icon:SetTexture(FF_Icon);
		ff.icon:SetPoint("TOPLEFT", self, "TOPLEFT", 1, -1);
		ff.icon:SetWidth(18);
		ff.icon:SetHeight(18);
		
		bp.icon = self:CreateTexture(nil, "OVERLAY"); bp.icon:ClearAllPoints(); bp.icon:SetTexture(BP_Icon);
		bp.icon:SetPoint("TOPLEFT", self, "TOPLEFT", 1, -21);
		bp.icon:SetWidth(18);
		bp.icon:SetHeight(18);
		
		-- Bars
		self.Bars = {};
		self.Bars["ff"] = ff;
		self.Bars["bp"] = bp;
		
		self.isRunning = true;
	end

	self:RegisterEvent("UNIT_AURA");
	self:RegisterEvent("PLAYER_TARGET_CHANGED");

	self.last = 0;
	self:SetScript("OnEvent", function(frame, event, ...) frame[event](frame, ...); end );
	self:SetScript("OnUpdate", function(frame, elapsed) frame:OnUpdate(elapsed); end );
	
end

function TRB_Diseases:UpdateDiseaseBar(disease)
		local bar = self.Bars[disease];

		local name, _, icon, _,_,  duration, expirationTime, _ = UnitAura("target", bar.id, nil, "PLAYER|HARMFUL");
		
		if name then
			local val = expirationTime - GetTime();
			local valT = format("%.0f", val);
			if( val < 5 ) then valT = format("%.1f", val); end
			if( val < 0 ) then valT = ""; end;
			local val = (val / duration) * 100;
			bar:SetValue(val);
			
			bar.text:SetText( valT );
--			bar:Show();
		else
--			bar:Hide();
			bar:SetValue(0);
			bar.text:SetText();
		end
end

function TRB_Diseases:showBars(v)
	if(v) then
		self:Show();
		self.needUpdate = true;
	else
		self:Hide();
		--self:SetFrameStrata("MEDIUM");
		self.needUpdate = false;
		self.Bars["ff"]:SetValue(0);
		self.Bars["bp"]:SetValue(0);
	end
end

function TRB_Diseases:UNIT_AURA(unit)
end

function TRB_Diseases:PLAYER_TARGET_CHANGED()
	if( UnitExists("target")) then
		self:showBars(true);
	else
		self:showBars(false);
	end
end

function TRB_Diseases:OnUpdate(elapsed)
	self.last = self.last + elapsed;
	
	if( self.last > 0.01 ) then
		if( self.needUpdate) then
			self:UpdateDiseaseBar("ff");
			self:UpdateDiseaseBar("bp");
		end
		
		self.last = 0;
	end
end


-- Register Disease module
ThreeRuneBars:RegisterModule("Diseases", TRB_Diseases);

