if select(2, UnitClass("player")) ~= "DEATHKNIGHT" then
   return
end
-----------------------------------------------------------------------------------
-- Info on panels: http://www.wowwiki.com/Using_the_Interface_Options_Addons_panel
-----------------------------------------------------------------------------------
TRB_Options = {};

function TRB_Options:init()

	self:LoadConfig();

	local panel = CreateFrame("frame", "ThreeRuneBars_Options", UIParent);
	panel.name = "Three Rune Bars";
	panel.okay = function() TRB_Options:Okay(TRB_Options); end
	panel.cancel = function() TRB_Options:Cancel(TRB_Options); end
	panel.default = function() TRB_Options:Default(TRB_Options); end

	--
	-- Main panel
	--
	local xoff, yoff = 20, -20;
	
	local header = panel:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
	header:SetPoint("TOPLEFT", panel, "TOPLEFT", xoff, yoff);
	header:SetText(panel.name.." v"..GetAddOnMetadata("ThreeRunebars", "Version") );
	panel.header = header;
	
	-- Disease Tracker
	local cb = CreateFrame("CheckButton", "TRB_DiseaseStatus", panel, "InterfaceOptionsCheckButtonTemplate");
	cb:SetPoint("TOPLEFT", panel, "TOPLEFT", xoff, yoff-40);
	cb.text = _G[cb:GetName().."Text"];
	cb.text:SetText("Use Disease tracker module");
	local v = false;
	if( not (TRB_Config.disabled_modules and TRB_Config.disabled_modules[name] and TRB_Config.disabled_modules[name] == true) ) then
		v = true;
	end
	cb:SetChecked( v );
	self.CB_diseases = cb;
	
	-- Scale
	local slider = CreateFrame("slider", "TRB_ScaleSlider", panel, "OptionsSliderTemplate");
	slider:SetPoint("TOPLEFT", panel, "TOPLEFT", xoff, yoff-90);
	slider:SetWidth(200);
	slider:SetHeight(20);
	slider:SetOrientation("HORIZONTAL");
	slider:SetMinMaxValues(0.1, 2.0);
	slider:SetValue(1);
	slider:SetValueStep(0.1);
	_G[slider:GetName().."Low"]:SetText("0.1");
	_G[slider:GetName().."High"]:SetText("2.0");
	slider.Text = _G[slider:GetName().."Text"];
	slider:SetScript("OnValueChanged", function(self, value) TRB_Options:SetScaleValue(self, value); end);
	slider:SetScript("OnShow", function(self) self:SetValue(TRB_Config.Scale or 1.0); end);
	slider.Text:SetText( format("Set Scale: %.1f", slider:GetValue()) );
	slider:Show();
	self.ScaleSlider = slider;
	
	
	--
	-- Add panel to blizzards addon config
	--
	self.panel = panel;
	InterfaceOptions_AddCategory(self.panel);
end

function TRB_Options:LoadConfig(forceReset)
	
	if(not TRB_Config or TRB_Config == false or forceReset) then
		DEFAULT_CHAT_FRAME:AddMessage("TRB: Default config loaded.");
		
		if(forceReset) then self.oldCfg = TRB_Config; end
		
		TRB_Config = nil;
		TRB_Config = TRB_Config_Defaults;
	else
		DEFAULT_CHAT_FRAME:AddMessage("TRB: User config loaded.");
	
		-- User config exists, but may need to restore some needed values.
		
		if(not TRB_Config.Colors) then
			-- No colors, Load default colors
			TRB_Config.Colors = TRB_Config_Defaults.Colors; 
		end

		if (not TRB_Config.Positions or forceReset ) then
			-- No positions, Load default positions
			TRB_Config.Positions = TRB_Config_Defaults.Positions; 
		end
	end
	
	ThreeRuneBars:StartModules();
end

function TRB_Options:Okay()

	DEFAULT_CHAT_FRAME:AddMessage("TRB: Okay");
	
	local cb = _G["TRB_DiseaseStatus"];
	
	-- Diseases
		--local status = self.CB_diseases:GetChecked();
		local status = cb:GetChecked();
		DEFAULT_CHAT_FRAME:AddMessage("Status: "..(status and "true" or "nil") );
		DEFAULT_CHAT_FRAME:AddMessage("isRunning: "..(ThreeRuneBars.modules["Diseases"].isRunning and "true" or "nil") );
		if( status and not ThreeRuneBars.modules["Diseases"].isRunning ) then
			DEFAULT_CHAT_FRAME:AddMessage("TRB: Enable Diseases module.");
			TRB_Config["disabled_modules"]["Diseases"] = nil;
--			ThreeRuneBars.modules["Diseases"]:init();
			
		elseif( not status and ThreeRuneBars.modules["Diseases"].isRunning) then
			DEFAULT_CHAT_FRAME:AddMessage("TRB: Disable Diseases module.");
			if( not TRB_Config.disabled_modules ) then TRB_Config.disabled_modules = {}; end
			TRB_Config["disabled_modules"]["Diseases"] = true;
--			ThreeRuneBars.modules["Diseases"]:Disable();
		end
		
	-- Scale
		local scale = self.ScaleSlider:GetValue();
		if( not TRB_Config.Scale or TRB_Config.Scale ~= scale ) then
			DEFAULT_CHAT_FRAME:AddMessage( format("TRB: New scale value saved: %.1f",scale) );
			TRB_Config.Scale = scale;
		end
		
	ThreeRuneBars:StartModules();
end

function TRB_Options:Cancel()
	-- Reset values to what they was before configuration started.
	DEFAULT_CHAT_FRAME:AddMessage("TRB: Discards changes");
	
	-- Modules
		-- Don't have to do anything
	
	-- Reset Scale
		ThreeRuneBars:ChangeScale(TRB_Config.Scale or 1.0);
end

function TRB_Options:Default()
	self:LoadConfig(true);
	
	self.ScaleSlider:SetValue(TRB_Config.Scale or 1.0);
--	ThreeRuneBars:ChangeScale(TRB_Config.Scale or 1.0);
end

function TRB_Options:SetScaleValue(slider, value)
	slider.Text:SetText(format("Set Scale: %.1f", value) );

	-- Update scale to get a preview of how big the frames is.
	ThreeRuneBars:ChangeScale(value);	
end









-- add Options to TRB
ThreeRuneBars.Options = TRB_Options;

---
--- Slash handling
---
SLASH_TRB1, SLASH_TRB2 = "/trb", "/ThreeRuneBars";

local function TRB_SlashHandler(msg, editbox)

--	InterfaceOptionsFrame_OpenToCategory(TRB_Options.panel);
--	return;

	if(msg == "config") then
		InterfaceOptionsFrame_OpenToCategory(TRB_Options.panel);
	elseif( not msg or msg=="" or msg=="lock" or msg=="unlock" ) then
		if( ThreeRuneBars.isLocked ) then
			ThreeRuneBars:Unlock();
		else
			ThreeRuneBars:Lock();
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("Usage:");
		DEFAULT_CHAT_FRAME:AddMessage(" /trb - Lock/Unlock");
		DEFAULT_CHAT_FRAME:AddMessage(" /trb config - Open configuration.");
	end

end
SlashCmdList["TRB"] = TRB_SlashHandler;
